# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## [0.3.0] - 2019-12-24
### Added
- use the env vars as defaults

## [0.2.0] - 2019-11-25
### Fixed
- output the result to stdout

## [0.1.0] - 2019-11-22
### Added
- parse templates
